package com.odweta.solon

import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import org.json.JSONObject
import java.io.File
import java.nio.charset.Charset

class Account(val username: String, val password: String, private val error: Int) {
    companion object {
        private fun parseAccountDataFile(file: File): Account {
            val lines: List<String> = file.readLines()

            if (lines.size >= 2) {
                if (lines[0] != "" && lines[1] != "") {
                    return Account(lines[0], lines[1], 0)
                }
            }

            return Account("", "", 1)
        }

        fun haveSaved(): Boolean {
            /* check if a file exists
             *   no -> create it and return false
             *   yes -> read the contents and use them as the username and password
             */

            // check if file exists
            val file = File(global.fileDir, global.filePaths.accountData)

            return if (!file.exists()) {
                // it does not exist
                file.createNewFile()
                false
            } else {
                // it exists, so it shall be parsed
                val acc: Account = parseAccountDataFile(file)
                global.username = acc.username
                global.password = acc.password
                acc.error == 0
            }
        }

        fun save(acc: Account): Boolean {
            return try {
                val file = File(global.fileDir, global.filePaths.accountData)
                file.writeText("${acc.username}\n${acc.password}\n", Charset.forName("UTF-8"))

                true
            } catch (e: Exception) {
                false
            }
        }

        suspend fun isValid(acc: Account): Boolean {
            return withContext(Dispatchers.IO) {
                global.username = acc.username
                global.password = acc.password

                val token = networkRequestFactory.perform(NetworkRequestType.Token).getString("token")
                !JSONObject(token).has("error")
            }
        }
    }
}