package com.odweta.solon

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.toArgb
import com.odweta.solon.ui.theme.SolonTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        window.statusBarColor = Color.Black.toArgb()
        global.fileDir = applicationContext.filesDir

        launchStart(applicationContext)

        setContent {
            SolonTheme {
                when (global.currentScreen) {
                    Screen.Main -> if (global.launched) MainScreen()
                    Screen.Splash -> SplashScreen()
                    Screen.SignIn -> SignInScreen()
                }
            }
        }
    }

    @Composable
    fun MainScreen() {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(Color.Black)
        ) {
            Box(
                modifier = global.modifiers.bar,
                contentAlignment = Alignment.Center
            ) {
                ToolbarScreen()
            }

            Box(
                modifier = Modifier
                    .fillMaxWidth()
                    .weight(1f)
            ) {
                when (global.currentScreenElement) {
                    ScreenElement.Timetable -> TimetableScreen()
                    ScreenElement.Marks -> MarksScreen()
                    ScreenElement.Menu -> MenuScreen()
                    ScreenElement.About -> AboutScreen()
                    ScreenElement.Settings -> SettingsScreen()
                }
            }

            Box(
                modifier = global.modifiers.bar,
                contentAlignment = Alignment.Center
            ) {
                NavbarScreen()
            }
        }
    }
}