package com.odweta.solon

import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.material3.Button
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.ButtonDefaults
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.odweta.solon.ui.theme.PastelYellow
import kotlin.system.exitProcess

@Composable
fun MenuScreen() {
    var showDialog by remember { mutableStateOf(false) }

    Column(
        modifier = Modifier
            .fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        MenuButton({ showDialog = true }, "Odhlásit se")

        Spacer(modifier = Modifier.height(80.dp))

        MenuButton({ global.currentScreen = Screen.SignIn }, "Změnit přihlášení")

        Spacer(modifier = Modifier.height(80.dp))

        MenuButton({ global.currentScreenElement = ScreenElement.About }, "O aplikaci")

        Spacer(modifier = Modifier.height(80.dp))

        MenuButton({ global.currentScreenElement = ScreenElement.Settings }, "Nastavení")
    }

    // Dialog implementation
    if (showDialog) {
        AlertDialog(
            onDismissRequest = { showDialog = false },  // Close the dialog on dismiss
            title = {
                Text(text = "Odhlásit se", color = Color.White)
            },
            text = {
                Text("Opravdu se chcete odhlásit? Tato akce zavře aplikaci.", color = Color.White)
            },
            containerColor = Color.Black,
            modifier = Modifier
                .border(
                    width = global.dimens.borderWidth,
                    color = PastelYellow,
                    shape = RoundedCornerShape(global.dimens.roundedCorner)),  // Yellow border
            confirmButton = {
                Button(
                    onClick = {
                        showDialog = false
                        Util.deleteFile(global.filePaths.userData)
                        Util.deleteFile(global.filePaths.timetable)
                        Util.deleteFile(global.filePaths.marks)
                        Util.deleteFile(global.filePaths.accountData)
                        Util.deleteFile(global.filePaths.lectureNotes)
                        // do not delete settings
                        exitProcess(0)
                    },
                    colors = ButtonDefaults.buttonColors(
                        containerColor = Color.Black,   // Black background for the button
                        contentColor = Color.White     // Yellow text for the button
                    ),
                    modifier = Modifier
                        .border(
                            width = global.dimens.borderWidth,
                            color = PastelYellow,
                            shape = RoundedCornerShape(global.dimens.roundedCorner))  // Yellow border
                ) {
                    Text("Ano")
                }
            },
            dismissButton = {
                Button(
                    onClick = {
                        showDialog = false
                    },
                    colors = ButtonDefaults.buttonColors(
                        containerColor = Color.Black,   // Black background for the button
                        contentColor = Color.White,
                        // Yellow text for the button
                    ),
                    modifier = Modifier
                        .border(
                            width = global.dimens.borderWidth,
                            color = PastelYellow,
                            shape = RoundedCornerShape(global.dimens.roundedCorner))  // Yellow border
                ) {
                    Text("Ne")
                }
            }
        )
    }
}

@Composable
fun MenuButton(onClick: () -> Unit, text: String) {
    Button(
        onClick = onClick,
        colors = ButtonDefaults.buttonColors(
            contentColor = Color.White,
            containerColor = Color.Black
        ),
        modifier = Modifier
            .border(
                width = global.dimens.borderWidth,
                shape = RoundedCornerShape(global.dimens.roundedCorner),
                color = PastelYellow
            )
            .width(230.dp)
            .height(80.dp)
    ) {
        Text(
            text = text,
            fontSize = 23.sp
        )
    }
}