package com.odweta.solon

import androidx.activity.compose.BackHandler
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchColors
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.odweta.solon.ui.theme.PastelYellow

@Composable
fun SettingsScreen() {
    // handle the back gesture (back swipe form side or back button on bottom android navbar)
    BackHandler { global.currentScreenElement = ScreenElement.Menu }

    val scrollState = rememberScrollState()

    Column(modifier = Modifier
        .fillMaxSize()
        .background(color = Color.Black)
        .verticalScroll(scrollState)
    ) {
        backButtonFactory.get(BackButtonType.Menu)()

        Spacer(Modifier.height(10.dp))

        SettingsTableRow(settings.useSvobodaMode)

        Spacer(Modifier.height(10.dp))

        SettingsTableRow(settings.useAmoledMode)

        Spacer(Modifier.height(10.dp))

        SettingsTableRow(settings.showRefreshButton)
    }
}

@Composable
fun SettingsTableRow(setting: Setting) {
    Row(
        modifier = Modifier
            .padding(10.dp)
            .background(color = Color.Black, shape = RoundedCornerShape(global.dimens.roundedCorner))
            .fillMaxWidth(),
        verticalAlignment = Alignment.CenterVertically
    ) {
        Text(
            text = setting.name,
            textAlign = TextAlign.Start,
            color = Color.White,
            fontSize = 20.sp
        )

        Spacer(modifier = Modifier.weight(1f))

        Switch(
            checked = setting.checked.value,
            onCheckedChange = {
                setting.checked.value = it
                when (setting.id) {
                    SettingsId.Svoboda -> settings.useSvobodaMode = setting
                    SettingsId.Amoled -> settings.useAmoledMode = setting
                    SettingsId.RefreshButton -> settings.showRefreshButton = setting
                    else -> {}
                }
                Util.saveStringToFile(global.filePaths.settings, settings.toString())
            },
            colors = SwitchColors(
                uncheckedThumbColor = Color.Black,
                uncheckedTrackColor = Color.DarkGray,
                uncheckedBorderColor = Color.DarkGray,
                checkedThumbColor = Color.Black,
                checkedTrackColor = PastelYellow,
                checkedBorderColor = PastelYellow,
                checkedIconColor = Color.White,
                uncheckedIconColor = Color.White,
                disabledCheckedThumbColor = Color.Black,
                disabledCheckedTrackColor = Color.Black,
                disabledCheckedBorderColor = Color.Black,
                disabledCheckedIconColor = Color.Black,
                disabledUncheckedThumbColor = Color.Black,
                disabledUncheckedTrackColor = Color.Black,
                disabledUncheckedBorderColor = Color.Black,
                disabledUncheckedIconColor = Color.Black
            )
        )
    }
}

fun String.toSettingsData(): SettingsData {
    val settings = this.split("\n")
    if (settings.size <= 1) {
        return SettingsData()
    }
    val auxSettingsData = SettingsData()
    val useSvobodaMode = settings[0].split("#")
    val useAmoledMode = settings[1].split("#")
    val showRefreshButton = settings[2].split("#")

    auxSettingsData.useSvobodaMode.id = SettingsId.Svoboda
    auxSettingsData.useSvobodaMode.name = useSvobodaMode[1]
    auxSettingsData.useSvobodaMode.checked.value = useSvobodaMode[2].toBoolean()

    auxSettingsData.useAmoledMode.id = SettingsId.Amoled
    auxSettingsData.useAmoledMode.name = useAmoledMode[1]
    auxSettingsData.useAmoledMode.checked.value = useAmoledMode[2].toBoolean()

    auxSettingsData.showRefreshButton.id = SettingsId.RefreshButton
    auxSettingsData.showRefreshButton.name = showRefreshButton[1]
    auxSettingsData.showRefreshButton.checked.value = showRefreshButton[2].toBoolean()

    return auxSettingsData
}