package com.odweta.solon

import android.util.Log
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.DisposableEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.setValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch
import org.json.JSONObject

@Composable
fun ToolbarScreen() {
    // make the font size adaptive relative to the length of the user's name
    var toolbarTextSizeAdaptive by remember { mutableStateOf(25.sp) }

    if (global.status.length > 28) {
        toolbarTextSizeAdaptive = 20.sp
    }

    if (global.status.length > 32) {
        toolbarTextSizeAdaptive = 16.sp
    }

    if (global.status.length > 40) {
        toolbarTextSizeAdaptive = 12.sp
    }

    if (global.status.length > 45) {
        toolbarTextSizeAdaptive = 10.sp
    }

    Box(modifier = Modifier.padding(10.dp)) {
        Text(
            text = global.status,
            fontSize = toolbarTextSizeAdaptive,
            color = Color.White
        )
    }
}

enum class StatusType {
    NameRole,
    NoInternet,
    Loading
}

private interface StatusFactoryInterface {
    fun show(type: StatusType)
}

object StatusFactory: StatusFactoryInterface {
    override fun show(type: StatusType) {
        when (type) {
            StatusType.NameRole -> {
                val role = if (Parsing.userIsParent()) {
                    " – Rodič"
                } else {
                    " – Student"
                }

                showStatus("${global.userData.getString("fullName")}$role")
            }
            StatusType.NoInternet -> {
                showStatus("Bez připojení k internetu.")
            }
            StatusType.Loading -> {
                CoroutineScope(Dispatchers.IO).launch {
                    global.refreshed = false
                    val anim = listOf(
                        "Načítání nových dat",
                        "Načítání nových dat.",
                        "Načítání nových dat..",
                        "Načítání nových dat...",
                        "Načítání nových dat..",
                        "Načítání nových dat."
                    )
                    var i = 0
                    while (!global.refreshed) {
                        if (i == anim.size) i = 0
                        showStatus(anim[i++])
                        delay(300)
                    }
                }
            }
        }
    }
}

val statusFactory = StatusFactory

fun showStatus(text: String) {
    global.status = text
}